import random
import string
import random

class Vs():
    def __init__(self):
        self.version = 0.1


class Generator():
    def __init__(self):

        #Nitro Generator

        self.tyx = "ABCDEFGHIJKLMNOPQRSTUVWYXZabcdefghijklmnopqrstuvwxyz123456789"
        self.a1 = random.choice(self.tyx)
        self.a2 = random.choice(self.tyx)
        self.a3 = random.choice(self.tyx)
        self.a4 = random.choice(self.tyx)
        self.a5 = random.choice(self.tyx)
        self.a6 = random.choice(self.tyx)
        self.a7 = random.choice(self.tyx)
        self.a8 = random.choice(self.tyx)
        self.a9 = random.choice(self.tyx)
        self.a10 = random.choice(self.tyx)
        self.a11 = random.choice(self.tyx)
        self.a12 = random.choice(self.tyx)
        self.a13 = random.choice(self.tyx)
        self.a14 = random.choice(self.tyx)
        self.a15 = random.choice(self.tyx)
        self.a16 = random.choice(self.tyx)
        self.nitro = "https://discord.gift/" + self.a1+self.a2+self.a3+self.a4+self.a5+self.a6+self.a7+self.a8+self.a9+self.a10+self.a11+self.a12+self.a13+self.a14+self.a15+self.a16


import os
from setuptools import setup

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "slxvfs",
    version = "0.0.1",
    author = "Sx",
    author_email = "orencape@gmail.com",
    description = ('SLX - '),
    license = None,
    keywords = ["slx", "slm", "slf", "generator", "giftcard generator"],
    url = "http://packages.python.org/slxvfs",
    long_description=read('README.txt'),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ]
)
